@@ -72,7 +72,9 @@
 #' @param use_units If the Hmisc package's units() function has been employed
 #'  it may be interesting to have a column at the far right that indicates the
 #'  unit measurement. If this column is specified then the total column will
-#'  appear before the units (if specified as last).
+#'  appear before the units (if specified as last). You can also set he value to
+#'  \code{"name"} and the units will be added to the name as a parenthesis,
+#'  e.g. Age (years).
 #' @param percentage_sign If you want to surpress the percentage sign you
 #'  can set this variable to FALSE. You can also choose something else that
 #'  the default \% if you so wish by setting this variable.
@@ -92,10 +94,8 @@
 #'
 #' @family descriptive functions
 #'
-#' @importFrom Hmisc label
-#' @importFrom Hmisc label<-
-#' @importFrom Hmisc units
-#' @importFrom Hmisc capitalize
+#' @importFrom Hmisc label label<- units capitalize
+#' @importFrom stats na.omit
 #'
 #' @export
 getDescriptionStatsBy <- function(x,
@@ -338,12 +338,15 @@ getDescriptionStatsBy <- function(x,
             useNA.digits = useNA.digits,
             default_ref = default_ref, percentage_sign = percentage_sign)
 
-    # Set the rowname to a special format
-    # if there was missing and this is an matrix
-    # then we should avoid using this format
-    name <- sprintf("%s %s",
-                    capitalize(levels(x)[default_ref]),
-                    tolower(label(x)))
+    # Check that we're dealing with only one row
+    if (unique(sapply(t, length)) == 1)
+      # Set the rowname to a special format
+      # if there was missing and this is an matrix
+      # then we should avoid using this format
+      name <- sprintf("%s %s",
+                      capitalize(levels(x)[default_ref]),
+                      tolower(name))
+
     if (NEJMstyle) {
       # LaTeX needs and escape before %
       # or it marks the rest of the line as
@@ -387,7 +390,7 @@ getDescriptionStatsBy <- function(x,
 
   getHeader <- function (tbl_cnt, header_count, html) {
     if (missing(header_count) ||
-          !header_count){
+          identical(header_count, FALSE)){
       return(names(tbl_cnt))
     }
 
@@ -462,20 +465,28 @@ getDescriptionStatsBy <- function(x,
   }
 
   if (use_units){
-    if (units(x) != ""){
-      unitcol <- rep(sprintf("%s",units(x)), times=NROW(results))
-      unitcol[rownames(results) == "Missing"] <- ""
+    if(is.logical(use_units)){
+      if (units(x) != ""){
+        unitcol <- rep(sprintf("%s",units(x)), times=NROW(results))
+        unitcol[rownames(results) == "Missing"] <- ""
+      }else{
+        unitcol <- rep("", times=NROW(results))
+      }
+      if (length(unitcol) != nrow(results)){
+        stop("There is an discrepancy in the number of rows in the units",
+             " and the by results: ", length(unitcol), " units vs ", nrow(results), " results",
+             "\n Units:", paste(unitcol, collapse=", "),
+             "\n Rows results:", paste(rownames(results), collapse=", "))
+      }
+      results <- cbind(results, unitcol)
+      cn <- c(cn, "units")
+    }else if(use_units == "name"){
+      if (units(x) != ""){
+        name <- sprintf("%s (%s)", name, units(x))
+      }
     }else{
-      unitcol <- rep("", times=NROW(results))
+      stop("The units use suggested has not yet been implemented, only logical or 'name' are.")
     }
-    if (length(unitcol) != nrow(results)){
-      stop("There is an discrepancy in the number of rows in the units",
-           " and the by results: ", length(unitcol), " units vs ", nrow(results), " results",
-           "\n Units:", paste(unitcol, collapse=", "),
-           "\n Rows results:", paste(rownames(results), collapse=", "))
-    }
-    results <- cbind(results, unitcol)
-    cn <- c(cn, "units")
   }
 
   if (is.function(statistics)){
