@@ -279,6 +279,15 @@ test_that("Check factor function with missing",
   expect_equal(a, target)
 })
 
+test_that("Check txtInt application",{
+  # Check for factors
+  set.seed(10)
+  test_var <- factor(sample(1:3, size = 10^4, replace = TRUE))
+  out <- prGetStatistics(test_var,
+                         useNA ="no", show_all_values=FALSE)
+  expect_true(any(grepl(",", out)))
+})
+
 test_that("Problem with boolean x", {
   set.seed(1)
   aa <- factor(sample(c("No", "Yes"), size = 50, replace = TRUE))
@@ -301,36 +310,36 @@ test_that("Error when one category has no missing in it", {
   aa[aaa == 2 & is.na(aa)] <- "B"
   ret <-
     getDescriptionStatsBy(x = aa, by=aaa, add_total_col = TRUE)
-  
+
   expect_match(ret["A","2"], sprintf("^%d", table(aa, aaa)["A","2"]),
                info="The value does not seem to match the raw table")
   expect_match(ret["B","2"], sprintf("^%d", table(aa, aaa)["B","2"]),
                info="The value does not seem to match the raw table")
   expect_match(ret["Missing","2"], "^0")
-  
+
   ret <-
     getDescriptionStatsBy(x = aa, by=aaa, useNA="no", add_total_col = TRUE)
   expect_match(ret[1,"2"], sprintf("^%d", table(aa, aaa)["A","2"]),
                info="The value does not seem to match the raw table")
   expect_equal(nrow(ret), 1)
-  
+
   ret <-
-    getDescriptionStatsBy(x = aa, by=aaa, 
+    getDescriptionStatsBy(x = aa, by=aaa,
                           add_total_col = TRUE,
-                          useNA="no", 
+                          useNA="no",
                           prop_fn = describeFactors)
   expect_match(ret["A","2"], sprintf("^%d", table(aa, aaa)["A","2"]),
                info="The value does not seem to match the raw table")
   expect_match(ret["B","2"], sprintf("^%d", table(aa, aaa)["B","2"]),
                info="The value does not seem to match the raw table")
-  
+
   cont <- rnorm(length(aa))
   cont[sample(1:50, size = 5)] <- NA
   cont[aaa == 2 & is.na(cont)] <- 0
   ret <-
     getDescriptionStatsBy(x = cont, by=aaa, useNA="no", add_total_col = TRUE)
   expect_equal(nrow(ret), 1)
-  
+
   aa <- factor(sample(LETTERS[1:3], size = 50, replace = TRUE))
   aa[sample(1:50, size = 5)] <- NA
   aaa <- factor(sample(1:2, size = 50, replace = TRUE))
@@ -341,8 +350,8 @@ test_that("Error when one category has no missing in it", {
                info="The value does not seem to match the raw table")
   expect_match(ret["B","2"], sprintf("^%d", table(aa, aaa)["B","2"]),
                info="The value does not seem to match the raw table")
-  
-  
+
+
 })
 
 test_that("Error when one continuous variable has no missing in it", {
@@ -360,13 +369,58 @@ test_that("Error when one continuous variable has no missing in it", {
 
 test_that("Error when a factor variable has an empty level", {
   set.seed(1)
-  variable <- factor(sample(LETTERS[1:2], size = 50, replace = TRUE), 
+  variable <- factor(sample(LETTERS[1:2], size = 50, replace = TRUE),
                      levels = LETTERS[1:3])
   variable[sample(1:50, size = 5)] <- NA
   by <- factor(sample(1:2, size = 50, replace = TRUE))
   ret <-
     getDescriptionStatsBy(x = variable, by=by, add_total_col = TRUE, useNA="no")
-  
+
   expect_match(ret["B","2"],
                sprintf("^%d", sum(variable[by == 2] == "B", na.rm=TRUE)))
 })
+
+
+test_that("test header", {
+  data(mtcars)
+
+  mtcars$am <- factor(mtcars$am, levels=0:1, labels=c("Automatic", "Manual"))
+  Hmisc::label(mtcars$am) <- "Transmission"
+  set.seed(666)
+  mtcars$col <- factor(sample(c("red", "black", "silver"),
+                              size=NROW(mtcars), replace=TRUE))
+
+  out <- getDescriptionStatsBy(
+    x=mtcars$col,
+    by=mtcars$am,
+    header_count = TRUE,
+    add_total_col = TRUE,
+    statistics = TRUE
+  )
+  expect_match(colnames(out)[1],
+               sprintf("No. %d", nrow(mtcars)))
+  expect_match(colnames(out)[2],
+               sprintf("No. %d",
+                       sum(mtcars$am == levels(mtcars$am)[1])))
+  expect_match(colnames(out)[3],
+               sprintf("No. %d",
+                       sum(mtcars$am != levels(mtcars$am)[1])))
+
+
+  out <- getDescriptionStatsBy(
+    x=mtcars$col,
+    by=mtcars$am,
+    header_count = "(n = %s)",   # custom header
+    add_total_col = TRUE,
+    statistics = TRUE
+  )
+
+  expect_match(colnames(out)[1],
+               sprintf("\\(n = %d\\)", nrow(mtcars)))
+  expect_match(colnames(out)[2],
+               sprintf("\\(n = %d\\)",
+                       sum(mtcars$am == levels(mtcars$am)[1])))
+  expect_match(colnames(out)[3],
+               sprintf("\\(n = %d\\)",
+                       sum(mtcars$am != levels(mtcars$am)[1])))
+})
